

set -ex



test -L $PREFIX/lib/libnppc.so.12.3.0.116
test -L $PREFIX/lib/libnppc.so.12
test -L $PREFIX/targets/sbsa-linux/lib/libnppc.so.12
test -f $PREFIX/targets/sbsa-linux/lib/libnppc.so.12.3.0.116
exit 0
